﻿'***************************************************************************************************
'   サンプル用データベースI/O関連定数(MDB用)                   modAboutMDB1(Module)
'
'   作成者:井上治  URL:https://www.ne.jp/asahi/excel/inoue/ [Excelでお仕事!]
'***************************************************************************************************
'   ※この下に「データベースI/Oクラス(MDB用)(clsAboutMDB)」があります
'***************************************************************************************************
' 変更日付 Rev     変更履歴内容-------------------------------------------------------------------->
' 17/01/15(1.0.0.0)新規作成
' 17/01/18(1.0.0.0)GetDataTableOleは処理成否を返す仕様に変更
' 17/03/11(1.0.0.0)ACCDBでの変更箇所をコメントで追加する対応
'***************************************************************************************************
Imports System.IO
Module modAboutMDB1
    '===============================================================================================
    ' WorkTable名
    Friend Const g_cnsMdbTempTable1 As String = "MdbTempTable1"
    Friend Const g_cnsMdbTempTable2 As String = "MdbTempTable2"
    Friend Const g_cnsMdbTempTable3 As String = "MdbTempTable3"
    ' エラーメッセージ
    Friend Const g_cnsMDBMSG001 As String = "データベースに接続できませんでした。"
    Friend Const g_cnsMDBMSG002 As String = "データベースの更新に失敗しました。"
    Friend Const g_cnsMDBMSG003 As String = "データベースの参照に失敗しました。"
    Friend Const g_cnsMDBMSG011 As String = "このコードのデータは既に登録されています。"
    Friend Const g_cnsMDBMSG012 As String = "このコードのデータは登録されていません。"
    Friend Const g_cnsMDBMSG013 As String = "このコードのデータは既に削除済みです。"
    Friend Const g_cnsMDBMSG021 As String = "出力対象データが存在しません。"
End Module

'***************************************************************************************************
'   サンプル用データベースI/Oクラス(MDB用)                     clsAboutMDB1(Class)
'
'   作成者:井上治  URL:http://www.ne.jp/asahi/excel/inoue/ [Excelでお仕事!]
'***************************************************************************************************
' 変更日付 Rev     変更履歴内容-------------------------------------------------------------------->
' 17/01/15(1.0.0.0)新規作成
' 17/01/18(1.0.0.0)GetDataTableOleは処理成否を返す仕様に変更
'***************************************************************************************************
Friend Class clsAboutMDB1
    '===============================================================================================
    Private Const g_cnsMDB_Connect1 = "Provider=Microsoft.Jet.OLEDB.4.0;Data Source='"
    'Private Const g_cnsMDB_Connect1 = "Provider=Microsoft.ACE.OLEDB.12.0;Data Source='" ' ←ACCDBの場合
    '-----------------------------------------------------------------------------------------------
    Private g_strConnectionString As String = ""                    ' 接続文字列
    Private g_objOwnerForm As Form = Nothing                        ' 親フォーム

    '***********************************************************************************************
    '   ■■■ 初期化 ■■■
    '***********************************************************************************************
    '* 処理名　：New
    '* 機能　　：初期化
    '-----------------------------------------------------------------------------------------------
    '* 返り値　：(なし)
    '* 引数　　：Arg1 = 親フォーム(Object)
    '* 　　　　　Arg2 = MDBファイル名(String)
    '* 　　　　　Arg3 = MDBサブフォルダ名(String)
    '* 　　　　　Arg4 = MDBの接続ユーザーID(String)     ※Option
    '* 　　　　　Arg5 = MDBの接続パスワード(String)     ※Option
    '-----------------------------------------------------------------------------------------------
    '* 作成日　：2017年01月15日
    '* 作成者　：井上　治
    '* 更新日　：2017年01月15日
    '* 更新者　：井上　治
    '* 機能説明：
    '* 注意事項：
    '***********************************************************************************************
    Friend Sub New(ByVal objOwnerForm As Form, _
                   ByVal strMdbFilename As String, _
                   ByVal strMdbSubFolder As String, _
                   Optional ByVal strMdbUserId As String = "", _
                   Optional ByVal strMdbPassword As String = "")
        '-------------------------------------------------------------------------------------------
        g_objOwnerForm = objOwnerForm
        ' MDB接続文字列の編集
        g_strConnectionString = FP_GetMdbConnectionString(strMdbFilename, _
                                                          strMdbSubFolder, _
                                                          strMdbUserId, _
                                                          strMdbPassword)
    End Sub

    '***********************************************************************************************
    '   ■■■ OleDbアクセス関連共通サブ処理 ■■■
    '***********************************************************************************************
    '* 処理名　：GetDataTableOle
    '* 機能　　：データテーブルを取得(OLE非接続処理)
    '-----------------------------------------------------------------------------------------------
    '* 返り値　：処理成否(Boolean)
    '* 引数　　：Arg1 = DataTable(Object)                ※Ref参照(戻り値)
    '* 　　　　　Arg2 = SQL文(String)
    '* 　　　　　Arg3 = 参照テーブルID(String)           ※カッコ付きテーブル名
    '* 　　　　　Arg4 = エラーメッセージ(String)         ※Option(エラー表示させない時の通知用)
    '* 　　　　　Arg5 = データテーブル名(String)         ※Option
    '* 　　　　　Arg6 = エラー表示スイッチ(Boolean)      ※Option(内部でエラー表示させる)
    '* 　　　　　Arg7 = 無データエラースイッチ(Boolean)  ※Option(0件をエラー扱いにしない)
    '-----------------------------------------------------------------------------------------------
    '* 作成日　：2017年01月15日
    '* 作成者　：井上　治
    '* 更新日　：2017年01月18日
    '* 更新者　：井上　治
    '* 機能説明：データテーブル名は"MdbTempTable1"がデフォルト
    '* 注意事項：
    '***********************************************************************************************
    Friend Function GetDataTableOle(ByRef dbTbl As DataTable, _
                                    ByVal strSQL As String, _
                                    ByVal strTableName As String, _
                                    Optional ByRef strFatalErrMSG As String = "", _
                                    Optional ByVal strWorkTable As String = g_cnsMdbTempTable1, _
                                    Optional ByVal swDispError As Boolean = True, _
                                    Optional ByVal swNoDataError As Boolean = False) As Boolean
        '-------------------------------------------------------------------------------------------
        Dim strMSG As String = g_cnsMDBMSG001                       ' エラーメッセージ
        dbTbl = Nothing
        Using dbCon As New OleDb.OleDbConnection, dbDSet As New DataSet
            Try
                '-----------------------------------------------------------------------------------
                ' MDBコネクションを取得
                dbCon.ConnectionString = g_strConnectionString
                '-----------------------------------------------------------------------------------
                ' 参照SQLの発行(DataAdapter)
                strMSG = g_cnsMDBMSG003
                Using dbDAdp As New OleDb.OleDbDataAdapter(strSQL, dbCon)
                    ' DataSetを取得
                    dbDAdp.Fill(dbDSet, strWorkTable)
                    ' DataTableを返す
                    dbTbl = dbDSet.Tables(strWorkTable)
                    ' 0件確認
                    If (swNoDataError AndAlso (dbTbl.Rows.Count = 0)) Then
                        ' 0件をエラーとする場合の処置
                        strFatalErrMSG = g_cnsMDBMSG021 & FP_ChangeRoundBrackets(strTableName)
                        ' メッセージ表示
                        If swDispError Then
                            MessageBox.Show(g_objOwnerForm, _
                                            strFatalErrMSG, _
                                            g_objOwnerForm.Text, _
                                            MessageBoxButtons.OK, _
                                            MessageBoxIcon.Error)
                        End If
                        Return False
                    End If
                End Using
                Return True

            Catch ex As Exception
                '-----------------------------------------------------------------------------------
                ' 接続・参照不成功(一般例外)
                strFatalErrMSG = strMSG & FP_ChangeRoundBrackets(strTableName) & _
                    ControlChars.CrLf & ex.Message
                ' メッセージ表示
                If swDispError Then
                    MessageBox.Show(g_objOwnerForm, _
                                    strFatalErrMSG, _
                                    g_objOwnerForm.Text, _
                                    MessageBoxButtons.OK, _
                                    MessageBoxIcon.Error)
                End If
                Return False
            End Try
        End Using
    End Function

    '***********************************************************************************************
    '   ■■■ 共通サブ処理(Private) ■■■
    '***********************************************************************************************
    '* 処理名　：FP_GetMdbConnectionString
    '* 機能　　：MDB接続文字列の編集
    '-----------------------------------------------------------------------------------------------
    '* 返り値　：MDB接続文字列(String)
    '* 引数　　：Arg1 = MDBファイル名(String)
    '* 　　　　　Arg2 = マイドキュメント配下のサブフォルダ(String)
    '* 　　　　　Arg3 = ユーザーID(String)
    '* 　　　　　Arg4 = パスワード(String)
    '-----------------------------------------------------------------------------------------------
    '* 作成日　：2017年01月15日
    '* 作成者　：井上　治
    '* 更新日　：2017年01月15日
    '* 更新者　：井上　治
    '* 機能説明：マイドキュメント配下のサブフォルダを指定してMDB接続文字列を編集
    '* 注意事項：
    '***********************************************************************************************
    Private Function FP_GetMdbConnectionString(ByVal strMDBName As String, _
                                               ByVal strSubFolder As String, _
                                               ByVal strUserId As String, _
                                               ByVal strPassword As String) As String
        '-------------------------------------------------------------------------------------------
        Dim strPathname As String = My.Computer.FileSystem.SpecialDirectories.MyDocuments ' フォルダ
        ' サブフォルダ指定あり
        If strSubFolder.Length <> 0 Then
            strPathname = Path.Combine(strPathname, strSubFolder)
        End If
        ' MDBファイル名を接続したフルパス名を編集
        Dim strFilename As String = Path.Combine(strPathname, strMDBName) ' ファイル名
        ' MDBの接続文字列を編集
        Dim strConnectionString As String = g_cnsMDB_Connect1       ' 接続文字列
        strConnectionString &= strFilename & "';"
        ' ユーザーIDが指定されている
        If strUserId.Length <> 0 Then
            strConnectionString &= "User ID='" & strUserId & "';"
        End If
        ' パスワードが指定されている
        If strPassword.Length <> 0 Then
            strConnectionString &= "Password='" & strPassword & "';"
        End If
        Return strConnectionString
    End Function

    '***********************************************************************************************
    '* 処理名　：FP_ChangeRoundBrackets
    '* 機能　　：鍵カッコを丸カッコに変換(共通処理)
    '-----------------------------------------------------------------------------------------------
    '* 返り値　：変換後文字列(String)
    '* 引数　　：Arg1 = 変換前文字列(String)
    '-----------------------------------------------------------------------------------------------
    '* 作成日　：2017年01月15日
    '* 作成者　：井上　治
    '* 更新日　：2017年01月15日
    '* 更新者　：井上　治
    '* 機能説明：例："[TableName]"を"(TableName)"に変換する(例外メッセージ表示用)
    '* 注意事項：先頭文字が"["でない場合はそのまま返す
    '***********************************************************************************************
    Private Function FP_ChangeRoundBrackets(ByVal strInTableName As String) As String
        '-------------------------------------------------------------------------------------------
        Const cnsKA As String = "("
        Const cnsKO As String = ")"
        Const cnsKA2 As String = "["
        Const cnsKO2 As String = "]"
        Const cnsKOKA2 As String = "].["
        Const cnsDOT As String = "."
        If strInTableName.Length = 0 Then Return strInTableName
        ' 先頭文字が"["か
        If strInTableName.StartsWith(cnsKA2) Then
            ' 中間の"].["を"."のみに変換
            Dim strText As String = strInTableName.Replace(cnsKOKA2, cnsDOT)
            ' 先頭文字が"["の場合は丸カッコに変換する
            Return cnsKA & strText.Substring(1, strText.Length - 2) & cnsKO
        ElseIf strInTableName.StartsWith(cnsKA) Then
            ' 先頭文字が"("の場合はそのまま返す
            Return strInTableName
        ElseIf strInTableName.EndsWith(cnsKO2) Then
            ' 右端のみ"]"が付いている場合の対応
            Dim strText As String = strInTableName.Substring(0, strInTableName.Length - 1)
            Return cnsKA & strText & cnsKO
        Else
            ' 上記以外の場合は"("～")"で挟む
            Return cnsKA & strInTableName & cnsKO
        End If
    End Function

    '----------------------------------------<< End of Source >>------------------------------------
End Class
