﻿'***************************************************************************************************
'   サンプル用共通モジュール①                                modCommonModule1(Module)
'
'   作成者:井上治  URL:https://www.ne.jp/asahi/excel/inoue/ [Excelでお仕事!]
'***************************************************************************************************
' 変更日付 Rev     変更履歴内容-------------------------------------------------------------------->
' 17/01/15(1.0.0.0)新規作成
'***************************************************************************************************
Module modCommonModule1
    '===============================================================================================
    ' [共通定数]
    ' 日付チェック用定数
    Friend Const g_cnsDefaultDate As Date = #12/31/1899#
    Friend Const g_cnsMinimumDate As Date = #1/1/1900#
    Friend Const g_cnsMaximumDate As Date = #12/31/2049#
    ' 日付NULL時の代替値
    Friend Const g_cnsNullDate As Date = Nothing
    ' 標準フォント名
    Friend Const g_cnsStdFontName As String = "ＭＳ ゴシック"
    Friend Const g_cnsStdFontNameP As String = "ＭＳ Ｐゴシック"
    ' 標準フォントサイズ
    Friend Const g_cnsFontSize900 As Single = 9.0F
    Friend Const g_cnsFontSize975 As Single = 9.75F
    ' 共通利用固定文字
    Friend Const g_cnsFormatDate As String = "yyyy-MM-dd"
    Friend Const g_cnsFormatDate2 As String = "yyyy/MM/dd"

    '***********************************************************************************************
    '   ■■■ 一般共通サブ処理 ■■■
    '***********************************************************************************************
    '* 処理名　：FP_EditDate
    '* 機能　　：日付表示用編集処理(一覧表示用：デフォルトはyyyy/MM/dd編集)
    '-----------------------------------------------------------------------------------------------
    '* 返り値　：編集後の日付(String)
    '* 引数　　：Arg1 = 日付値(Object:String)
    '* 　　　　　Arg2 = 日付フォーマット(String)     ※Option
    '-----------------------------------------------------------------------------------------------
    '* 作成日　：2017年01月15日
    '* 作成者　：井上　治
    '* 更新日　：2017年01月15日
    '* 更新者　：井上　治
    '* 機能説明：
    '* 注意事項：Null日付等はブランクが返る
    '***********************************************************************************************
    Friend Function FP_EditDate(ByVal objInDate As Object, _
                                Optional ByVal strDateFormat As String = g_cnsFormatDate2) As String
        '-------------------------------------------------------------------------------------------
        Dim dteDate As Date                                         ' 日付WORK
        Dim strDate As String = String.Empty                        ' 文字列WORK
        ' NULL値でなければ値(文字列)を取り出す
        If ((Not DBNull.Value.Equals(objInDate)) AndAlso (objInDate IsNot Nothing)) Then
            strDate = objInDate.ToString.Trim
        End If
        ' 有効な日付か判定
        If ((strDate.Length <> 0) AndAlso _
            (Date.TryParse(strDate, dteDate)) AndAlso _
            (dteDate >= g_cnsMinimumDate) AndAlso _
            (dteDate < g_cnsMaximumDate)) Then
            ' 日付をフォーマット編集
            Return dteDate.ToString(strDateFormat)
        Else
            ' NGはブランクを返す
            Return String.Empty
        End If
    End Function

    '----------------------------------------<< End of Source >>------------------------------------
End Module
